@@ -150,6 +150,10 @@ pub enum Encounter {
     FraenirOfJormag = Boss::FraenirOfJormag as u16,
     Boneskinner = Boss::Boneskinner as u16,
     WhisperOfJormag = Boss::WhisperOfJormag as u16,
+    CaptainMaiTrin = Boss::CaptainMaiTrin as u16,
+    Ankka = Boss::Ankka as u16,
+    MinisterLi = Boss::MinisterLi as u16,
+    Dragonvoid = 0x0562,
 }
 
 impl Encounter {
@@ -202,6 +206,10 @@ impl Encounter {
             Encounter::FraenirOfJormag => &[Boss::FraenirOfJormag],
             Encounter::Boneskinner => &[Boss::Boneskinner],
             Encounter::WhisperOfJormag => &[Boss::WhisperOfJormag],
+            Encounter::CaptainMaiTrin => &[Boss::CaptainMaiTrin],
+            Encounter::Ankka => &[Boss::Ankka],
+            Encounter::MinisterLi => &[Boss::MinisterLi],
+            Encounter::Dragonvoid => &[],
         }
     }
 
@@ -221,6 +229,7 @@ impl Encounter {
         match id {
             _ if id == Encounter::TwistedCastle as u16 => Some(Encounter::TwistedCastle),
             _ if id == Encounter::RiverOfSouls as u16 => Some(Encounter::RiverOfSouls),
+            _ if id == Encounter::Dragonvoid as u16 => Some(Encounter::Dragonvoid),
             _ => Boss::from_u16(id).map(Boss::encounter),
         }
     }
@@ -241,7 +250,9 @@ impl Encounter {
             | CardinalSabir | QadimThePeerless => GameMode::Raid,
 
             IcebroodConstruct | Boneskinner | SuperKodanBrothers | FraenirOfJormag
-            | WhisperOfJormag => GameMode::Strike,
+            | WhisperOfJormag | CaptainMaiTrin | Ankka | MinisterLi | Dragonvoid => {
+                GameMode::Strike
+            }
 
             StandardKittyGolem | MediumKittyGolem | LargeKittyGolem => GameMode::Golem,
         }
@@ -273,6 +284,7 @@ impl FromStr for Encounter {
             "eyes" | "statue of darkness" => Ok(Encounter::StatueOfDarkness),
             "largos" | "twins" | "largos twins" | "twin largos" => Ok(Encounter::TwinLargos),
             "kodans" | "super kodan brothers" => Ok(Encounter::SuperKodanBrothers),
+            "dragonvoid" | "the dragonvoid" => Ok(Encounter::Dragonvoid),
 
             _ => Err(ParseEncounterError(s.to_owned())),
         }
@@ -322,6 +334,10 @@ impl Display for Encounter {
             Encounter::FraenirOfJormag => "Fraenir of Jormag",
             Encounter::Boneskinner => "Boneskinner",
             Encounter::WhisperOfJormag => "Whisper of Jormag",
+            Encounter::CaptainMaiTrin => "Captain Mai Trin",
+            Encounter::Ankka => "Ankka",
+            Encounter::MinisterLi => "Minister Li",
+            Encounter::Dragonvoid => "The Dragonvoid",
         };
         write!(f, "{}", name)
     }
@@ -545,6 +561,18 @@ pub enum Boss {
     ///
     /// [Guild Wars 2 Wiki](https://wiki.guildwars2.com/wiki/Whisper_of_Jormag)
     WhisperOfJormag = 0x58B7,
+    /// Captain Mai Trin, boss of the Aetherblade Hideout strike mission.
+    ///
+    /// [Guild Wars 2 Wiki](https://wiki.guildwars2.com/wiki/Strike_Mission:_Aetherblade_Hideout)
+    CaptainMaiTrin = 0x5DE1,
+    /// Ankka, boss in the Xunlai Jade Junkyard.
+    ///
+    /// [Guild Wars 2 Wiki](https://wiki.guildwars2.com/wiki/Strike_Mission:_Xunlai_Jade_Junkyard)
+    Ankka = 0x5D95,
+    /// Minister Li, boss in the Kaineng Overlook.
+    ///
+    /// [Guild Wars 2 Wiki](https://wiki.guildwars2.com/wiki/Strike_Mission:_Kaineng_Overlook)
+    MinisterLi = 0x5FA5,
 }
 
 impl Boss {
@@ -595,6 +623,9 @@ impl Boss {
             Boss::FraenirOfJormag => Encounter::FraenirOfJormag,
             Boss::Boneskinner => Encounter::Boneskinner,
             Boss::WhisperOfJormag => Encounter::WhisperOfJormag,
+            Boss::CaptainMaiTrin => Encounter::CaptainMaiTrin,
+            Boss::Ankka => Encounter::Ankka,
+            Boss::MinisterLi => Encounter::MinisterLi,
         }
     }
 }
@@ -664,6 +695,9 @@ impl FromStr for Boss {
             "fraenir" | "fraenir of jormag" => Ok(Boss::FraenirOfJormag),
             "boneskinner" => Ok(Boss::Boneskinner),
             "whisper" | "whisper of jormag" => Ok(Boss::WhisperOfJormag),
+            "captain mai trin" | "mai trin" | "mai" => Ok(Boss::CaptainMaiTrin),
+            "ankka" => Ok(Boss::Ankka),
+            "minister li" | "li" => Ok(Boss::MinisterLi),
 
             _ => Err(ParseBossError(s.to_owned())),
         }
@@ -717,6 +751,9 @@ impl Display for Boss {
             Boss::FraenirOfJormag => "Fraenir of Jormag",
             Boss::Boneskinner => "Boneskinner",
             Boss::WhisperOfJormag => "Whisper of Jormag",
+            Boss::CaptainMaiTrin => "Captain Mai Trin",
+            Boss::Ankka => "Ankka",
+            Boss::MinisterLi => "Minister Li",
         };
         write!(f, "{}", name)
     }
@@ -815,6 +852,17 @@ pub enum EliteSpec {
     Mirage = 59,
     Scourge = 60,
     Renegade = 63,
+
+    // End of Dragons elites:
+    Willbender = 65,
+    Bladesworn = 68,
+    Mechanist = 70,
+    Untamed = 72,
+    Specter = 71,
+    Catalyst = 67,
+    Virtuoso = 66,
+    Harbinger = 64,
+    Vindicator = 69,
 }
 
 impl FromStr for EliteSpec {
@@ -842,6 +890,16 @@ impl FromStr for EliteSpec {
             "scourge" => Ok(EliteSpec::Scourge),
             "renegade" => Ok(EliteSpec::Renegade),
 
+            "willbender" => Ok(EliteSpec::Willbender),
+            "bladesworn" => Ok(EliteSpec::Bladesworn),
+            "mechanist" => Ok(EliteSpec::Mechanist),
+            "untamed" => Ok(EliteSpec::Untamed),
+            "specter" => Ok(EliteSpec::Specter),
+            "catalyst" => Ok(EliteSpec::Catalyst),
+            "virtuoso" => Ok(EliteSpec::Virtuoso),
+            "harbinger" => Ok(EliteSpec::Harbinger),
+            "vindicator" => Ok(EliteSpec::Vindicator),
+
             _ => Err(ParseEliteSpecError(s.to_owned())),
         }
     }
@@ -868,6 +926,15 @@ impl Display for EliteSpec {
             EliteSpec::Mirage => "Mirage",
             EliteSpec::Scourge => "Scourge",
             EliteSpec::Renegade => "Renegade",
+            EliteSpec::Willbender => "Willbender",
+            EliteSpec::Bladesworn => "Bladesworn",
+            EliteSpec::Mechanist => "Mechanist",
+            EliteSpec::Untamed => "Untamed",
+            EliteSpec::Specter => "Specter",
+            EliteSpec::Catalyst => "Catalyst",
+            EliteSpec::Virtuoso => "Virtuoso",
+            EliteSpec::Harbinger => "Harbinger",
+            EliteSpec::Vindicator => "Vindicator",
         };
         write!(f, "{}", name)
     }
@@ -881,15 +948,15 @@ impl EliteSpec {
     pub fn profession(self) -> Profession {
         use EliteSpec::*;
         match self {
-            Dragonhunter | Firebrand => Profession::Guardian,
-            Berserker | Spellbreaker => Profession::Warrior,
-            Scrapper | Holosmith => Profession::Engineer,
-            Druid | Soulbeast => Profession::Ranger,
-            Daredevil | Deadeye => Profession::Thief,
-            Tempest | Weaver => Profession::Elementalist,
-            Chronomancer | Mirage => Profession::Mesmer,
-            Reaper | Scourge => Profession::Necromancer,
-            Herald | Renegade => Profession::Revenant,
+            Dragonhunter | Firebrand | Willbender => Profession::Guardian,
+            Berserker | Spellbreaker | Bladesworn => Profession::Warrior,
+            Scrapper | Holosmith | Mechanist => Profession::Engineer,
+            Druid | Soulbeast | Untamed => Profession::Ranger,
+            Daredevil | Deadeye | Specter => Profession::Thief,
+            Tempest | Weaver | Catalyst => Profession::Elementalist,
+            Chronomancer | Mirage | Virtuoso => Profession::Mesmer,
+            Reaper | Scourge | Harbinger => Profession::Necromancer,
+            Herald | Renegade | Vindicator => Profession::Revenant,
         }
     }
 }
@@ -1027,6 +1094,20 @@ mod tests {
             ("kodans", SuperKodanBrothers),
             ("whisper", WhisperOfJormag),
             ("Whisper of Jormag", WhisperOfJormag),
+            ("captain mai trin", CaptainMaiTrin),
+            ("Captain Mai Trin", CaptainMaiTrin),
+            ("mai trin", CaptainMaiTrin),
+            ("Mai Trin", CaptainMaiTrin),
+            ("ankka", Ankka),
+            ("Ankka", Ankka),
+            ("minister li", MinisterLi),
+            ("Minister Li", MinisterLi),
+            ("li", MinisterLi),
+            ("Li", MinisterLi),
+            ("dragonvoid", Dragonvoid),
+            ("Dragonvoid", Dragonvoid),
+            ("the dragonvoid", Dragonvoid),
+            ("The Dragonvoid", Dragonvoid),
         ];
 
         for (input, expected) in tests {
@@ -1161,6 +1242,16 @@ mod tests {
             ("Voice of the Fallen", VoiceOfTheFallen),
             ("whisper", WhisperOfJormag),
             ("Whisper of Jormag", WhisperOfJormag),
+            ("captain mai trin", CaptainMaiTrin),
+            ("Captain Mai Trin", CaptainMaiTrin),
+            ("mai trin", CaptainMaiTrin),
+            ("Mai Trin", CaptainMaiTrin),
+            ("ankka", Ankka),
+            ("Ankka", Ankka),
+            ("minister li", MinisterLi),
+            ("Minister Li", MinisterLi),
+            ("li", MinisterLi),
+            ("Li", MinisterLi),
         ];
 
         for (input, expected) in tests {
@@ -1246,38 +1337,56 @@ mod tests {
             ("Dragonhunter", Dragonhunter),
             ("firebrand", Firebrand),
             ("Firebrand", Firebrand),
+            ("willbender", Willbender),
+            ("Willbender", Willbender),
             ("berserker", Berserker),
             ("Berserker", Berserker),
             ("spellbreaker", Spellbreaker),
             ("Spellbreaker", Spellbreaker),
+            ("bladesworn", Bladesworn),
+            ("Bladesworn", Bladesworn),
             ("herald", Herald),
             ("Herald", Herald),
             ("renegade", Renegade),
             ("Renegade", Renegade),
+            ("vindicator", Vindicator),
+            ("Vindicator", Vindicator),
             ("daredevil", Daredevil),
             ("Daredevil", Daredevil),
             ("deadeye", Deadeye),
             ("Deadeye", Deadeye),
+            ("specter", Specter),
+            ("Specter", Specter),
             ("scrapper", Scrapper),
             ("Scrapper", Scrapper),
             ("holosmith", Holosmith),
             ("Holosmith", Holosmith),
+            ("mechanist", Mechanist),
+            ("Mechanist", Mechanist),
             ("druid", Druid),
             ("Druid", Druid),
             ("soulbeast", Soulbeast),
             ("Soulbeast", Soulbeast),
+            ("untamed", Untamed),
+            ("Untamed", Untamed),
             ("tempest", Tempest),
             ("Tempest", Tempest),
             ("weaver", Weaver),
             ("Weaver", Weaver),
+            ("catalyst", Catalyst),
+            ("Catalyst", Catalyst),
             ("chronomancer", Chronomancer),
             ("Chronomancer", Chronomancer),
             ("mirage", Mirage),
             ("Mirage", Mirage),
+            ("virtuoso", Virtuoso),
+            ("Virtuoso", Virtuoso),
             ("reaper", Reaper),
             ("Reaper", Reaper),
             ("scourge", Scourge),
             ("Scourge", Scourge),
+            ("harbinger", Harbinger),
+            ("Harbinger", Harbinger),
         ];
 
         for (input, expected) in tests {
